;----------------------------------------------------------------------------------
; AutoHotkey script which monitors the photo booth screen to turn lights on and off
; using a Phidgets PhidgetInterfaceKit 1014 0/0/4 relay board or a PacLED driver
; board.
;
; The Phidgets drivers need to be installed before using this script with a Phidget
; relay board. The drivers can be downloaded from:
; http://www.phidgets.com
;
; Also works with the Pac LED driver board from Ultimarc (USA):
; http://www.ultimarc.com/pacdrive.html
; or from Gremlin Solutions (UK):
; http://www.gremlinsolutions.co.uk/products/leddriverboard.htm
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; This script works with:
; DSLR Remote Pro for Windows v1.9.1 or later
; NKRemote v1.4 or later
; PSRemote v1.9 or later
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
;----------------------------------------------------------------------------------

; Use this for Phidget relay board
;RelayExe = PhidgetRelay.exe

; Use this for Pac LED driver from Gremlin Solutions
RelayExe = PacLED.exe

#SingleInstance force
#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.

ResetRelays()

; loop forever monitoring the status of the photobooth screen by looking
; at the window title which is in the form:
; Breeze Systems Photobooth - <screen_pathname>
flashCounter = 0
Loop
{
	IfWinExist, Breeze Systems Photobooth
	{
		WinGetTitle, Title, Breeze Systems Photobooth
		if Title contains ready.jpg
		{
			if PreviousTitle not contains ready.jpg
			{
				RelayOn(1)	; ready screen has just been displayed - turn relay #1 on
			}
		}
		else if PreviousTitle contains ready.jpg
		{
			RelayOff(1)		; ready screen has just been removed - turn relay #1 off
		}

		if Title contains welcome.jpg
		{
			if PreviousTitle not contains welcome.jpg
			{
				RelayOn(2)	; welcome screen has just been displayed - turn relay #2 on
			}
		}
		else if PreviousTitle contains welcome.jpg
		{
			RelayOff(2)		; welcome screen has just been removed - turn relay #2 off
		}
		PreviousTitle := Title
	}
	else if RelayStatus
	{
		; photo booth isn't running - turn all relays off
		ResetRelays()
		PreviousTitle :=
	}

	; FlashLights(1)	; uncomment this line for flashing light on channel 1
	; FlashLights(2)	; uncomment this line for flashing light on channel 2

	flashCounter := mod(flashCounter + 1, 10)
	Sleep 100	; sleep for 1/10th sec to avoid hogging the processor
}
Return

; Flash 'channel' on and off
FlashLights(channel)
{
	global RelayStatus, RelayExe, flashCounter
	mask := (1 << (channel - 1))
	if (RelayStatus & mask)
	{
		if flashCounter = 0
		{
			status := RelayStatus | mask
			run %RelayExe% %status%,,Hide
		}
		else if flashCounter = 5
		{
			status := RelayStatus & ~mask
			run %RelayExe% %status%,,Hide
		}
	}
}

; Turn individual relay on
RelayOn(channel)
{
	global RelayStatus, RelayExe
	RelayStatus |= (1 << (channel - 1))
	run %RelayExe% %RelayStatus%,,Hide
}

; Turn individual relay off
RelayOff(channel)
{
	global RelayStatus, RelayExe
	RelayStatus &= ~(1 << (channel - 1))
	run %RelayExe% %RelayStatus%,,Hide
}

; Turn all relays off
ResetRelays()
{
	global RelayStatus, RelayExe
	RelayStatus = 0
	run %RelayExe% %RelayStatus%,,Hide
}

